#wrap {
  margin-top: 20px;
}

#wrap>h1 {
  display: none;
}

.oceanwp-tp-wrap {
  margin: 20px 0 20px 0;
  overflow-x: hidden;
  max-width: 1220px;
  min-width: 850px;
  display: block !important;
}

.oceanwp-tp-wrap .btn-primary.disabled,
.oceanwp-tp-wrap .btn-primary:disabled {
  color: #ffffff !important;
}

.oceanwp-tp-wrap div {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.oceanwp-tp-wrap a,
.oceanwp-tp-plugin-item {
  transition: all 0.1s ease-in-out;
  -webkit-transition: all 0.1s ease-in-out;
  -moz-transition: all 0.1s ease-in-out;
  -ms-transition: all 0.1s ease-in-out;
  -o-transition: all 0.1s ease-in-out;
}

.oceanwp-tp-wrap p {
  font-size: 16px;
}

.oceanwp-tp-wrap a,
.oceanwp-tp-wrap a:hover,
.oceanwp-tp-wrap a:active {
  color: #606060;
  text-decoration: none;
}

.oceanwp-tp-wrap p a,
.oceanwp-tp-wrap p a:hover,
.oceanwp-tp-wrap p a:active,
.oceanwp-tp-wrap h3 a,
.oceanwp-tp-wrap h3 a:hover,
.oceanwp-tp-wrap h3 a:active {
  color: #007bff;
  text-decoration: none;
}

a:not(.button):not(.btn):not(.top-bar-links):not(.banner-button)[target="_blank"]:after {
  font-family: dashicons;
  content: "\f103";
  font-size: 13px;
}

/**  Control panel Header **/
.oceanwp-tp-header {
  background: #161D30;
  width: 100%;
  padding: 15px 0px 15px 20px;
  border-top-right-radius: 6px;
  border-top-left-radius: 6px;
}

.oceanwp-tp-oceanwp-logo {
  display: inline-block;
  margin-top: 5px;
  background: url(../../../assets/images/logo.png) no-repeat center center;
  float: left;
  width: 170px;
  height: 50px;
}

.rtl .oceanwp-tp-oceanwp-logo {
  float: right;
}

.oceanwp-tp-branding strong {
  line-height: 55px;
  vertical-align: middle;
  padding-left: 25px;
  display: inline-block;
  float: left;
  margin-bottom: 0px;
  color: #FFFFFF;
  font-family: "Rubik", Sans-serif;
  font-size: 25px;
  font-weight: 400;
  margin-top: 2px;
}

.rtl .oceanwp-tp-branding strong {
  float: right;
  padding-right: 15px;
  padding-left: 0;
}

.oceanwp-tp-theme-version {
  float: right;
  line-height: 55px;
  display: inline-block;
  color: #F0F0F0;
  font-family: "Rubik", Sans-serif;
  font-size: 16px;
  font-weight: 400;
  padding-right: 25px;
  margin-top: 3px;
}

.rtl .oceanwp-tp-theme-version {
  float: left;
}

/***/
.oceanwp-tp-container {
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
  overflow: hidden;
  position: relative;
  border: 1px solid #e5e5e5;
}

.oceanwp-tp-sidebar {
  background-color: #F0F0F0;
  border-right: 1px solid #e5e5e5;
  width: 215px;
  float: left;
  height: 100%;
  padding-bottom: 50px;
  position: absolute;
  left: 0;
  top: 0;
}

.rtl .oceanwp-tp-sidebar {
  left: initial;
  right: 0;
  float: right;
  border-left: 1px solid #e5e5e5;
  border-right: 0;
}

.oceanwp-tp-sidebar-list {
  display: block;
  list-style: none;
  padding-top: 5px;
}

.oceanwp-tp-sidebar-list-items {
  margin: 0;
}

a.oceanwp-tp-sidebar-link {
  color: #212121;
  text-transform: capitalize;
  display: inline-block;
  text-decoration: none;
  margin: 15px 20px;
  font-family: "Rubik", Sans-serif;
  font-size: 18px;
  font-weight: 400;
}

a.oceanwp-tp-sidebar-link:focus {
  text-decoration: none;
  color: #069fdb;
  box-shadow: unset;
}

.oceanwp-tp-sidebar-link:hover {
  color: #069fdb;
  text-decoration-style: dashed;
  text-underline-position: under;
  transition: all 0.3s;
  -o-transition: all 0.3s;
  -webkit-transition: all 0.3s;
  -moz-transition: all 0.3s;
  -ms-transition: all 0.3s;

}

.oceanwp-tp-sidebar-list-items.oceanwp-is-active .oceanwp-tp-sidebar-link {
  color: #069fdb;
  text-decoration-style: dashed;
  text-underline-position: under;
  box-shadow: unset;
}

/** Panes **/
.oceanwp-tp-panes {
  background-color: #fff;
  float: left;
  min-height: 750px;
  padding-bottom: 50px;
  position: relative;
  margin-left: 200px;
  width: calc(100% - 200px);
}

.rtl .oceanwp-tp-panes {
  margin-left: initial;
  margin-right: 200px;
  float: right;
}

.oceanwp-tp-panes.loading-pane {
  opacity: 0.7;
}

.oceanwp-tp-pane-box {
  padding: 49px;
}

.oceanwp-tp-pane-box:first-of-type {
  display: block;
}

.oceanwp-tp-pane-box>h3 {
  font-size: 26px;
  color: #343a40;
  margin-bottom: 20px;
}

.oceanwp-tp-pane-box p:not(.oceanwp-tp-block-description) {
  margin: 0;
}

.oceanwp-tp-message-heading-block {
  display: flex;
  align-items: center;
  margin-top: 30px;
}

.oceanwp-tp-block-outer {
  display: flex;
}

.oceanwp-tp-pane-box .oceanwp-tp-wide-block:not(:first-child) {
  margin-top: 30px;
}

.oceanwp-tp-wide-block .oceanwp-tp-block-outer {
  align-items: center;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  padding-bottom: 20px;
}

.ocean-tp-heading-image {
  margin-right: 25px;
}

.oceanwp-tp-message-heading {
  margin-bottom: 0;
  color: #212121;
  font-family: poppins, Sans-serif;
  font-size: 22px;
  font-weight: 600;
}

.oceanwp-tp-large-block {
  background-color: #f4f4f4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin: 30px;
  padding: 25px;
  border-radius: 15px 15px 15px 15px;
}

.oceanwp-tp-block-inner {
  margin-left: 15px;
}

.oceanwp-tp-block-title,
h1#oceanwp-changelog,
#oceanwp-tp-changelog h3,
#oceanwp-tp-customizer .oceanwp-tp-block-title {
  margin-bottom: 10px;
  color: #212121;
  font-family: poppins, Sans-serif;
  font-size: 18px;
  font-weight: 600;
}

.oceanwp-tp-wide-block .oceanwp-tp-block-title {
  margin-bottom: 0px;
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 22px;
  font-weight: 600;
}

#oceanwp-tp-extra-settings .oceanwp-tp-wide-block .oceanwp-tp-block-title:not(.main-heading),
#oceanwp-tp-admin-settings .oceanwp-tp-wide-block .oceanwp-tp-block-title:not(.main-heading),
#oceanwp-tp-ocean-elementor-library .oceanwp-tp-wide-block .oceanwp-tp-block-title:not(.main-heading) {
  font-size: 18px;
}

.oceanwp-tp-small-block {
  background-color: #f4f4f4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin: 20px;
  padding: 10px;
  border-radius: 15px 15px 15px 15px;
}

.oceanwp-tp-small-block-title {
  margin-bottom: 5px;
  color: #212121;
  font-family: poppins, Sans-serif;
  font-size: 16px;
  font-weight: 600;
}

.oceanwp-tp-block-image {
  width: 42px;
  height: 42px;
}

.oceanwp-tp-block-image-small {
  width: 34px;
  height: 34px;
}

.oceanwp-tp-wide-block-image {
  width: 60px;
  height: 60px;
  margin-right: 25px;
}

.oceanwp-tp-block-description,
p.oceanwp-tp-block-description {
  color: #606060;
  font-family: poppins, Sans-serif;
  font-size: 15px;
}

#oceanwp-tp-useful-plugins .oceanwp-tp-block-description,
#oceanwp-tp-useful-plugins p.oceanwp-tp-block-description {
  line-height: 1.5;
  min-height: 6em;
}

.alert.oceanwp-tp-block-description,
p.alert.oceanwp-tp-block-description {
  color: #bd3434;
}

h3.oceanwp-tp-block-description,
#oceanwp-tp-integration p.oceanwp-tp-block-description,
#oceanwp-tp-install-demos p.oceanwp-tp-block-description,
#oceanwp-tp-home p strong {
  color: #606060;
  font-family: poppins, Sans-serif;
  font-size: 16px;
  font-weight: 400;
  line-height: 1.3em;
}


/** Banner **/
.oceanwp-tp-banner {
  background-position: center center;
  background-size: cover;
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin-top: 20px;
  margin-bottom: 20px;
  padding: 50px 30px;
  border-radius: 15px 15px 15px 15px;
  box-shadow: inset 2000px 0 0 0 rgba(33, 33, 33, 0.7);
  border-color: rgba(33, 33, 33, 1);
}

.oceanwp-tp-banner.help {
  background-image: url('../../../assets/images/banners/help.jpg');
}

.oceanwp-tp-banner.gunetberg-blocks {
  background-image: url('../../../assets/images/banners/gunetberg-blocks.jpg');
  margin-bottom: 50px;
  box-shadow: inset 2000px 0 0 0 rgb(33 33 33 / 80%);
}

.oceanwp-tp-banner.elementor-widgets {
  background-image: url('../../../assets/images/banners/elementor-widgets.jpg');
  margin-bottom: 50px;
}

.oceanwp-tp-banner.elementor-library {
  background-image: url('../../../assets/images/banners/elementor-library.jpg');
  margin-bottom: 50px;
}

.oceanwp-tp-banner.ocean-images {
  background-image: url('../../../assets/images/banners/ocean-images.jpg');
  margin-bottom: 50px;
  box-shadow: inset 2000px 0 0 0 rgb(33 33 33 / 80%);
}

.oceanwp-tp-banner.install-demos {
  background-image: url('../../../assets/images/banners/install-demos.jpg');
  margin-bottom: 50px;
}
.oceanwp-tp-banner.admin-settings {
  background-image: url('../../../assets/images/banners/admin-settings.jpg');
  margin-bottom: 50px;
}

.oceanwp-tp-banner.home {
  background-image: url('../../../assets/images/banners/home.jpg');
  margin-bottom: 50px;
}

.oceanwp-tp-banner.useful-plugins {
  background-image: url('../../../assets/images/banners/useful-plugins.jpg');
  margin-bottom: 50px;
}

.oceanwp-tp-banner.white-label {
  background-image: url('../../../assets/images/banners/white-label.jpg');
  margin-bottom: 50px;
  box-shadow: inset 2000px 0 0 0 rgb(33 33 33 / 65%);
}

h1.banner-header {
  color: #ffb100;
  font-family: poppins, Sans-serif;
  font-size: 25px;
  font-weight: 600;
}

.banner-subheader {
  color: #fff;
  font-family: poppins, Sans-serif;
  font-size: 17px;
  font-weight: 300;
}

#oceanwp-tp-home h2.banner-subheader {
  margin: 10px 0 40px 0;
}

a.banner-button {
  font-family: poppins, Sans-serif;
  font-size: 15px;
  font-weight: 600;
  text-transform: uppercase;
  color: #212121;
  background-color: #ffb100;
  border-radius: 8px 8px 8px 8px;
  padding: 12px 24px;
  display: inline-block;
  margin-top: 20px;
}

#oceanwp-tp-help a.banner-button {
  margin-top: 40px;
}

.oceanwp-icon-check-solid {
  width: 16px;
  height: 16px;
  background-image: url('../../../assets/images/check.svg');
  display: inline-block;
}

.oceanwp-tp-pane-features {
  margin-top: 30px;
}

#oceanwp-tp-home .oceanwp-tp-pane-features {
  padding: 15px;
}

.oceanwp-tp-pane-features li:not(:last-child) {
  padding-bottom: 4px;
}

.oceanwp-tp-pane-features li span {
  font-family: poppins, Sans-serif;
  font-size: 16px;
  font-weight: 500;
  color: #FFFFFF;
}

/** Free vs Pro **/
.oceanwp-tp-sidebar-link.oceanwp-sidebar-item-colored {
  color: #f23c97;
}

.oceanwp-ct-legend {
  display: flex;
  align-content: center;
  justify-content: space-between;
  align-items: center;
  flex-wrap: wrap;
  padding-bottom: 35px;
}

.oceanwp-ct-legend .legend-cell {
  display: flex;
  align-items: center;
  align-content: center;
  justify-content: center;
}

.oceanwp-ct-legend .legend-cell h3 {
  margin-top: 0;
}

.oceanwp-ct-legend .elementor-image-box-title {
  margin-left: 15px;
}

.oceanwp-ct-legend h3 {
  margin-bottom: 0px;
  font-size: 16px;
  font-weight: 500;
}

.oceanwp-comparison-table ul {
  margin: 0 0 50px 0;
}

.oceanwp-comparison-table ul:last-of-type {
  margin-bottom: 0;
}

.oceanwp-comparison-table ul li {
  display: grid;
  grid-template-columns: 3fr 1fr 1fr;
  padding: 15px 18px;
  font-size: 14px;
  align-items: center;
  margin-top: 7px;
}

.oceanwp-comparison-table ul li:not(:first-child) {
  border-bottom: 1px dashed rgba(226, 230, 235, 0.7);
}

.oceanwp-comparison-table ul li span:first-child {
  text-align: left;
}

.oceanwp-comparison-table .ct-table-heading {
  position: sticky;
  top: 50px;
  border-radius: 3px;
  background: #F0F0F0;

}

.oceanwp-comparison-table .ct-table-heading span,
.oceanwp .table thead th {
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 18px;
  font-weight: 600;
}

.oceanwp-ct-legend .oceanwp-ct-legend-heading {
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 18px;
  font-weight: 600;
}

.oceanwp-comparison-table ul li>span,
.oceanwp .table td {
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 16px;
  font-weight: 500;
}

.oceanwp-comparison-table .ct-table-heading:before {
  position: absolute;
  z-index: -1;
  content: '';
  top: -31px;
  left: 0;
  right: 0;
  height: 30px;
  background: #fff;
}

.oceanwp-ct-remark {
  padding: 10px;
}

.oceanwp-ct-remark.footer {
  display: flex;
  justify-content: flex-end;
}

.oceanwp-ct-remark h2 {
  color: #606060;
  font-family: "Poppins", Sans-serif;
  font-size: 16px;
  font-weight: 500;
}

.oceanwp-cancel-icon {
  width: 32px !important;
  height: 32px;
  background-image: url('../../../assets/images/icons/cancel.png');
  display: inline-block;
}

.oceanwp-tick-icon {
  width: 32px !important;
  height: 32px;
  background-image: url('../../../assets/images/icons/tick.png');
  display: inline-block;
}

.oceanwp-limited-icon {
  width: 32px !important;
  height: 32px;
  background-image: url('../../../assets/images/icons/limited.png');
  display: inline-block;
}

#oceanwp-tp-comparison .oceanwp-tp-small-block-image {
  width: 64px;
  height: 64px;
}

#oceanwp-tp-comparison .oceanwp-tp-small-block {
  margin: 20px 20px 20px 20px;
  padding: 10px 10px 10px 10px;
  border-radius: 15px 15px 15px 15px;
}


/** Theme Panel Switcher **/
.oceanwp-tp-switcher {
  position: relative;
  display: inline-block;
  width: 60px;
  height: 34px;
  order: 1;
}

.oceanwp-tp-switcher input {
  opacity: 0;
  width: 0;
  height: 0;
}

input:checked+.slider {
  background-color: #256077;
}

input:focus+.slider {
  box-shadow: 0 0 1px #256077;
}

input:checked+.slider:before {
  -webkit-transform: translateX(26px);
  -ms-transform: translateX(26px);
  transform: translateX(26px);
}

.slider.round {
  position: absolute;
  cursor: pointer;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: #ccc;
  -webkit-transition: .4s;
  transition: .4s;
  border-radius: 34px;
}

.slider.round:before {
  border-radius: 50%;
  position: absolute;
  content: "";
  height: 26px;
  width: 26px;
  left: 4px;
  bottom: 4px;
  background-color: white;
  -webkit-transition: .4s;
  transition: .4s;
}

/** Buttons **/
.oceanwp-tp-wrap .btn,
.oceanwp-tp-wrap .button,
.oceanwp-tp-wrap .button-primary {
  font-family: "Poppins", Sans-serif;
  font-size: 14px;
  font-weight: 500;
  background-color: #256077;
  color: #FFFFFF;
  border-radius: 5px 5px 5px 5px;
  border-color: unset;
}

.oceanwp-tp-wrap .btn:hover,
.oceanwp-tp-wrap .button:hover,
.oceanwp-tp-wrap .button-primary:hover,
.oceanwp-tp-wrap .btn:focus,
.oceanwp-tp-wrap .button:focus,
.oceanwp-tp-wrap .button-primary:focus {
  color: #FFFFFF;
  text-decoration: none;
  border-color: unset;
  box-shadow: unset;
  transition: all 0.3s;
  -o-transition: all 0.3s;
  -webkit-transition: all 0.3s;
  -moz-transition: all 0.3s;
  -ms-transition: all 0.3s;
}

.oceanwp-tp-wrap .btn.blue,
.oceanwp-tp-wrap .button.blue,
.oceanwp-tp-wrap .button.button-primary {
  background-color: #06214E;
  padding: 3px 24px;
}

.oceanwp-tp-wrap .btn.blue:hover,
.oceanwp-tp-wrap .button.blue:hover,
.oceanwp-tp-wrap .button.button-primary:hover {
  background-color: #163c80;
}

.oceanwp-tp-wrap .btn.yellow,
.oceanwp-tp-wrap .button.yellow {
  background-color: #ffb100;
  padding: 3px 24px;
  color: #06214E;
  border-color: transparent;
}

#ocean-customizer-reset,
#ocean-fonts-clear {
  margin-top: 20px;
}

#ocean-customizer-reset .btn,
#ocean-fonts-clear .btn {
  font-family: "Poppins", Sans-serif;
  font-size: 14px;
  font-weight: 500;
  background-color: #DB2B39;
  color: #FFFFFF;
  border-radius: 5px 5px 5px 5px;
  padding: 12px 24px;
}

#ocean-customizer-reset .btn:focus,
#ocean-fonts-clear .btn:focus {
  box-shadow: unset;
}

p.submit {
  text-align: right;
  margin-top: 30px !important;
}

/** Customizer **/
#ocean-customizer-control h3,
#ocean-gutenberg-blocks-items h3,
#ocean-elementor-widgets-items h3,
#ocean-metabox-items h3,
#ocean-widget-items h3 {
  margin-top: 25px;
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 15px;
  font-weight: 500;
  order: 2;
}

#ocean-metabox-items span.desc {
  order: 3;
}

#ocean-customizer-control .column-wrap:not(#ocean-customizer-reset-bulk) {
  width: 100%
}
#ocean-elementor-widgets-items #ocean-elementor-widgets-query-post {
  display: none;
}
#ocean-customizer-items,
#ocean-gutenberg-blocks-items,
#ocean-elementor-widgets-items,
#ocean-widget-items,
#ocean-metabox-items,
#ocean-elementor-library-tags-items,
.oceanwp-tp-useful-plugins-section,
.oceanwp-tp-recommended-plugins-section {
  display: flex;
  flex-wrap: wrap;
  margin-top: 30px;
}

#ocean-customizer-items div,
#ocean-gutenberg-blocks-items div,
#ocean-elementor-widgets-items div,
#ocean-widget-items>div,
#ocean-elementor-library-tags-items div,
#ocean-metabox-items div {
  flex-basis: 28%;
  padding: 20px;
  display: flex;
  align-content: center;
  align-items: flex-start;
  flex-direction: column;
}

.oceanwp-tp-useful-plugins-section>div,
.oceanwp-tp-recommended-plugins-section>div {
  flex-basis: 42%;
  margin-bottom: 10px;
}

.oceanwp-switcher-block {
  align-self: flex-start;
}

#oceanwp-tp-customizer .oceanwp-tp-block-image {
  margin-bottom: 30px;
}

#oceanwp-tp-customizer .oceanwp-tp-large-block {
  background-color: #f4f4f4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin: 30px;
  padding: 50px;
  border-radius: 15px 15px 15px 15px;
  display: flex;
  align-content: center;
  flex-direction: column;
  justify-content: flex-start;
}

#oceanwp-import-file {
  margin-bottom: 15px;
}

/** HOME **/
.quick-settings-block {
  margin-top: 30px;
}

.quick-settings .column-wrap {
  width: 100%
}

.quick-settings {
  display: flex;
  flex-wrap: wrap;
}

.quick-settings>div {
  flex-basis: 22%;
  margin-bottom: 10px;
}

.oceanwp-tp-quick-settings-block {
  background-color: #f4f4f4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin: 10px 10px 10px 10px;
  padding: 20px 20px 20px 20px;
  border-radius: 15px 15px 15px 15px;
}

.oceanwp-tp-quick-settings-block .title {
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 18px;
  font-weight: 600;
  margin: 10px 0 20px 0;
}

#ocean-metabox-items span.desc,
.oceanwp-tp-quick-settings-block p.desc {
  margin-bottom: 20px;
  color: #606060;
  font-family: poppins, Sans-serif;
  font-size: 14px;
}

#oceanwp-tp-home .oceanwp-tp-large-block {
  background-color: #f4f4f4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background .3s, border .3s, border-radius .3s, box-shadow .3s;
  margin: 0 30px 30px 30px;
  padding: 50px;
  border-radius: 15px 15px 15px 15px;
}

#oceanwp-tp-home .oceanwp-tp-block-title {
  margin: 20px 0;
}

#oceanwp-tp-help .oceanwp-tp-large-block .oceanwp-tp-block-title {
  margin-bottom: 20px;
}

.oceanwp-tp-top-panel,
.oceanwp-tp-upgrade-button-wrap {
  display: flex;
  justify-content: flex-end;
}

.oceanwp-tp-upgrade-button-wrap.last {
  justify-content: flex-start;
}

.oceanwp-tp-top-panel-inner {
  display: flex;
  max-width: 25%;
}

.oceanwp-top-panel-image {
  width: 22px;
  height: 22px;
  margin: 0 20px;
}

/** Changelog **/

#oceanwp-tp-changelog ul {
  margin-bottom: 10px;
  border-bottom: 1px solid #e1dcdc;
}

/** Install Demos  **/

#install-demos .theme-wrap {
  background-color: #F4F4F4;
  box-shadow: 2px 4px 6px -4px rgb(0 0 0 / 50%);
  transition: background 0.3s, border 0.3s, border-radius 0.3s, box-shadow 0.3s;
  margin: 10px 10px 10px 10px;
  padding: 20px 20px 20px 20px;
  border-radius: 15px 15px 15px 15px;
}

#install-demos .themes {
  margin: 5px;
}

#install-demos .theme-id-container h2 {
  color: #212121;
  font-family: "Poppins", Sans-serif;
  font-size: 18px;
  font-weight: 600;
  margin: 20px 0 50px 0;
}

#install-demos .theme-id-container h2,
#install-demos .ocean-theme-actions {
  text-align: center;

}

#install-demos .theme-wrap {
  width: 30%;
}

#install-demos .theme-browser .theme {
  border: unset;
  box-shadow: unset;
}

#install-demos .theme-browser .theme.focus:before,
#install-demos .theme-browser .theme:hover:before {
  cursor: pointer;
  content: "Import";
  color: #FFFFFF;
  font-family: "Poppins", Sans-serif;
  font-size: 18px;
  font-weight: 600;
  margin: 20px 0 50px 0;
  position: absolute;
  top: 25%;
  left: 50%;
  transform: translateX(-50%);
  z-index: 9999;
}

#install-demos .theme.focus .theme-screenshot,
#install-demos .theme:hover .theme-screenshot {
  background: #fff;
  box-shadow: inset 2000px 0 0 0 rgb(33 33 33 / 80%);
}

/** Save settings Notification Panel **/

.oceanwp-notify {
  display: none;
  position: absolute;
  bottom: 10px;
  right: 20px;
  width: 300px;
  color: white;
  text-align: left;
  background: rgba(92, 184, 17, 0.9);
  overflow: hidden;
  transition: height .2s;
  padding: 15px;
}

#oceanwp-notifyType:before {
  display: block;
  margin-top: 15px;

}

.oceanwp-notify.active {
  display: block;
  position: fixed;
  z-index: 5000;
  font-size: 16px;
}

/** Columns **/

.row {
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  margin-right: -15px;
  margin-left: -15px
}

.col {
  -ms-flex-preferred-size: 0;
  flex-basis: 0;
  -ms-flex-positive: 1;
  flex-grow: 1;
  max-width: 100%
}

.clearfix:before,
.clearfix:after,
.container:before,
.container:after,
.container-fluid:before,
.container-fluid:after,
.row:before,
.row:after {
  display: table;
  content: " ";
}

.clearfix:after,
.container:after,
.container-fluid:after,
.row:after {
  clear: both;
}

.oceanwp-tp-wrap h1,
.oceanwp-tp-wrap h2,
.oceanwp-tp-wrap h3,
.oceanwp-tp-wrap h4,
.oceanwp-tp-wrap h5,
.oceanwp-tp-wrap h6,
.oceanwp-tp-wrap ol,
.oceanwp-tp-wrap p,
.oceanwp-tp-wrap pre,
.oceanwp-tp-wrap ul {
  margin-top: 0;
}

/** System Info **/
.oceanwp table {
  border-collapse: collapse;
}

.oceanwp .table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 1rem;
  background-color: transparent;
}

.oceanwp .table th,
.oceanwp .table td {
  padding: 0.75rem;
  vertical-align: top;
  border-top: 1px solid #dee2e6;
}

.oceanwp .table thead th {
  vertical-align: bottom;
}

.oceanwp .table tbody+tbody {
  border-top: 2px solid #dee2e6;
}


.oceanwp .table .thead-light th {
  color: #495057;
  background-color: #F0F0F0;
}

.oceanwp .table-dark {
  color: #fff;
  background-color: #212529;
}

.oceanwp .table-dark th,
.oceanwp .table-dark td,
.oceanwp .table-dark thead th {
  border-color: #32383e;
}

.oceanwp .table-dark.table-bordered {
  border: 0;
}

.oceanwp .table-dark.table-striped tbody tr:nth-of-type(odd) {
  background-color: rgba(255, 255, 255, 0.05);
}

.oceanwp .table-dark.table-hover tbody tr:hover {
  background-color: rgba(255, 255, 255, 0.075);
}


.table td:first-child {
  width: 33%;
}

.table td.help {
  width: 20px;
  padding-right: 0;
  padding-left: 0;
}

.status-state {
  width: 20px;
  height: 20px;
  display: inline-block;
  vertical-align: bottom;
}

.status-state .spinner {
  float: none;
  margin: 0;
}

.status-true {
  background: url('../../../assets/images/icons/check-mark.svg') no-repeat;
  background-size: contain;
}

.status-false {
  background: url('../../../assets/images/icons/x-mark.svg') no-repeat;
  background-size: contain;
}

.status-invisible {
  visibility: hidden;
  position: absolute;
  left: 0;
  top: 0;
}

#oceanwp-textarea--get-system-report {
  display: none;
  margin: 10px 0;
  padding: 0;
  position: relative;
}

#oceanwp-textarea--get-system-report textarea {
  font-family: monospace;
  width: 100%;
  margin: 0;
  height: 300px;
  padding: 20px;
  border-radius: 0;
  resize: none;
  font-size: 12px;
  line-height: 20px;
  outline: 0;
  margin-bottom: 15px;
}

#get-system-report-button.oceanwp-button--get-system-report {
  float: right;
  margin: 20px 0;
}

.rtl .oceanwp-button--get-system-report {
  left: 25px;
  right: initial;
}

.oceanwp-wrap code {
  font-size: 87.5%;
  color: #e83e8c;
  word-break: break-word;
}

.oceanwp-tp-wrap .pro-plugins-update-notice {
  padding: 10px 20px;
}

.oceanwp-tp-tooltip {
  display: none;
}

.oceanwp-tp-wrap .button.upgrade-button {
  background: rgba(92, 184, 17, 0.9);
  border-radius: 3px;
  padding: 5px 15px;
}


/** White Label**/
#oceanwp-tp-white-label input[type="text"],
#oceanwp-tp-white-label textarea {
  min-width: 400px;
}

#oceanwp-tp-white-label th {
  min-width: 220px;
}

#oceanwp-tp-white-label #oceanwp_branding_screenshot_tr img {
  width: 100%;
}

#oceanwp-tp-white-label.oceanwp-tp-pane-box input[type="checkbox"]~p:not(.oceanwp-tp-block-description) {
  display: inline-block;
}


/** Preloader **/
.oceanwp-tp-preloader {
  display: none;
}

.oceanwp-tp-panes.loading-pane .oceanwp-tp-preloader {
  display: block;
  opacity: 0.7;
  position: fixed;
  left: 0;
  top: 0;
  z-index: 1001;
  background: #fafafa;
  height: 100vh;
  width: 100vw;
  overflow: hidden;
}

.oceanwp-tp-loader {
  position: relative;
  top: 50%;
  left: 50%;
  height: 5rem;
  width: 5rem;
  border-radius: 50%;
  border: 10px solid #ffb100;
  border-top-color: #06214e;
  box-sizing: border-box;
  background: transparent;
  animation: loading 1s linear infinite;
}

@keyframes loading {
  0% {
    transform: rotate(0deg);
  }

  0% {
    transform: rotate(360deg);
  }
}


@media (min-width: 768px) and (max-width: 1024px) {

  .oceanwp-tp-top-panel-inner {
    max-width: unset;
  }

  .oceanwp-tp-panes {
    margin-left: 180px;
  }

  .oceanwp-tp-wrap {
    max-width: unset;
    min-width: unset;
  }

  a.oceanwp-tp-sidebar-link {
    margin: 15px 20px 15px 8px;
    font-size: 16px;
  }

  #ocean-customizer-items,
  #ocean-elementor-widgets-items,
  #ocean-gutenberg-blocks-items,
  #ocean-metabox-items,
  #ocean-widget-items,
  .oceanwp-tp-recommended-plugins-section,
  .oceanwp-tp-useful-plugins-section {
    justify-content: space-between;
  }

  #ocean-customizer-items div,
  #ocean-elementor-widgets-items div,
  #ocean-gutenberg-blocks-items div,
  #ocean-metabox-items div,
  #ocean-widget-items>div {
    flex-basis: 38%;
  }

  #install-demos .theme-wrap {
    width: 40%;
  }

  .oceanwp-tp-recommended-plugins-section>div,
  .oceanwp-tp-useful-plugins-section>div {
    flex-basis: 100%;
  }

  #oceanwp-tp-white-label th {
    min-width: auto;
  }

  #oceanwp-tp-help .oceanwp-tp-help-section {
    display: block;
  }

  .quick-settings>div {
    flex-basis: 43%;
  }
}

@media (min-width: 320px) and (max-width: 480px) {
  .oceanwp-tp-header {
    display: flex;
    flex-direction: column;
    padding: 0;
  }

  .oceanwp-tp-branding {
    display: flex;
    flex-direction: column;
    align-items: center;
  }

  .oceanwp-tp-branding strong {
    padding-left: 0;
  }

  .oceanwp-tp-sidebar {
    width: auto;
    float: none;
    position: relative;
  }

  .oceanwp-tp-panes {
    margin-left: 0;
    width: auto;
  }

  .oceanwp-tp-wrap {
    min-width: auto;
  }

  .oceanwp-tp-theme-version {
    align-self: flex-end;
  }

  .oceanwp-tp-top-panel,
  .oceanwp-tp-upgrade-button-wrap {
    justify-content: flex-start;
  }

  .oceanwp-tp-pane-box {
    padding: 10px;
  }

  #oceanwp-tp-home .oceanwp-tp-large-block {
    margin: 20px;
    padding: 20px;
  }

  .quick-settings>div {
    flex-basis: 100%;
  }

  /* .oceanwp-tp-sidebar-list {
    margin-left: 8%;
  } */
  /* .oceanwp-tp-block-outer {
  display: inline-block;
  } */
  #oceanwp-tp-customizer .oceanwp-tp-large-block {
    margin: 20px;
    padding: 15px;
  }

  #ocean-customizer-items div,
  #ocean-gutenberg-blocks-items div,
  #ocean-elementor-widgets-items div,
  #ocean-widget-items>div,
  #ocean-metabox-items div {
    flex-basis: 100%;
  }

  #install-demos .theme-wrap {
    width: 100%;
  }

  .oceanwp-tp-useful-plugins-section>div,
  .oceanwp-tp-recommended-plugins-section>div {
    flex-basis: 100%;
  }

  .col {
    flex-basis: fit-content;
  }
}
